# server

## Schema Server

Server 定义了经典的长连接服务

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**name**<br />server 的名称|str|Undefined|**required**|
|**workloadType**<br />工作负载的类型|"Deployment" &#124; "StatefulSet" &#124; "DaemonSet"|"Deployment"|**required**|
|**replica**<br />目标副本数|int|1|**required**|
|**mainContainer**<br />主容器|Container|Undefined|**required**|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
